@@ -35,8 +35,10 @@ class OptDialog(QtGui.QDialog):
 
                 QtCore.QObject.connect(self.ui.btn_OptOK,
 QtCore.SIGNAL('clicked()'), self.doOK)
-                QtCore.QObject.connect(self.ui.btn_Reset,
-QtCore.SIGNAL('clicked()'), self.doReset)
+                QtCore.QObject.connect(self.ui.btn_Fast,
+QtCore.SIGNAL('clicked()'), self.doFast)
+                QtCore.QObject.connect(self.ui.btn_Quality,
+QtCore.SIGNAL('clicked()'), self.doQuality)
 
 	def doOK(self):
                 opts = self.ui.line_Options.text()
@@ -45,10 +47,13 @@ QtCore.SIGNAL('clicked()'), self.doReset)
                 f.close()
 		self.accept()
 
-	def doReset(self):		                        
-		f=open("/opt/tvcplayer/mplayeropts","r")
-                opts=f.read()
-                f.close()
+	def doFast(self):		                        
+                opts="-fs -cache 4096 -cache-min 25 -lavdopts fast:skiploopfilter=all -quiet -tsprobe 1000000 -vo xv:ck-method=auto -ao pulse -dr -hardframedrop"
+		self.ui.line_Options.setText(opts)
+		self.ui.line_Options.home(False)
+
+	def doQuality(self):		                        
+                opts="-fs -cache 4096 -cache-min 25 -quiet -tsprobe 1000000 -vo xv:ck-method=auto -ao pulse -dr -framedrop"
 		self.ui.line_Options.setText(opts)
 		self.ui.line_Options.home(False)
 
